@@ -130,7 +130,7 @@ if(!isset($CMS_ADMIN_PAGE) || $CMS_ADMIN_PAGE != 1)
 				);
 			}
 			
-			$params             =  isset($params['params']) && @is_array($params['params']) ? $params['params'] : array();
+			$params             = isset($params['params']) && @is_array($params['params']) ? $params['params'] : array();
 			$params['action']   = isset($params['action'])   ? $params['action']   : 'default';
 			$params['returnid'] = isset($params['returnid']) ? $params['returnid'] : get_pageid_or_alias_from_url();
 			$params['inline']   = true;
@@ -147,7 +147,7 @@ if(!isset($CMS_ADMIN_PAGE) || $CMS_ADMIN_PAGE != 1)
 				@ob_start();
 			}
 			
-			$module->DoAction($params['action'], 'mx_', $params, $params['returnid']);
+			$module->DoAction($params['action'], isset($params['id']) ? $params['id'] : 'cntnt01', $params, $params['returnid']);
 			$output = @ob_get_clean();
 			
 			if( isset($config['output_compression']) && ($config['output_compression']) && $config['debug'] != true )
@@ -410,6 +410,7 @@ function xajax_tools_loadURL(url) {
 			moduleParams[i.replace(new RegExp(result[2],'g'),'')] = moduleParams[i];
 			delete moduleParams[i];
 		}
+		moduleParams.id     = result[2];
 		moduleParams.action = result[3];
 	}
 	
@@ -802,6 +803,7 @@ Additionally there is a javascript function called <tt>xajax_tools()</tt> that m
 ?>
 
 <p>Author: Georg Busch (NaN)</p>
+<p>Version 0.3.2 - added module id to js function xajax_tools_loadURL()</p>
 <p>Version 0.3.1:<br />
  - minor bugfixes<br />
  - added js function xajax_tools_loadURL() using parseUri 1.2.2 (c) Steven Levithan &lt;stevenlevithan.com&gt;
